@@ -463,7 +463,7 @@ pub trait PanelState {
     ) -> Result<CmdResult, ProgramError> {
         let sel_info = self.sel_info(app_state);
         if let Some(invocation) = &invocation {
-            if let Some(error) = verb.check_args(&sel_info, &invocation, &app_state.other_panel_path) {
+            if let Some(error) = verb.check_args(&sel_info, invocation, &app_state.other_panel_path) {
                 debug!("verb.check_args prevented execution: {:?}", &error);
                 return Ok(CmdResult::error(error));
             }
@@ -478,7 +478,7 @@ pub trait PanelState {
                 &None
             },
         );
-        external_execution.to_cmd_result(w, exec_builder, &cc.app.con)
+        external_execution.to_cmd_result(w, exec_builder, cc.app.con)
     }
 
     fn execute_sequence(
@@ -614,7 +614,7 @@ pub trait PanelState {
                             InputPattern::none(),
                             prefered_mode,
                             self.tree_options(),
-                            &cc.app.con,
+                            cc.app.con,
                         )),
                         purpose: PanelPurpose::Preview,
                         direction: HDir::Right,
@@ -796,7 +796,7 @@ pub fn get_arg<T: Copy + FromStr>(
 ) -> T {
     verb_invocation
         .and_then(|vi| vi.args.as_ref())
-        .or_else(|| internal_exec.arg.as_ref())
+        .or(internal_exec.arg.as_ref())
         .and_then(|s| s.parse::<T>().ok())
         .unwrap_or(default)
 }
